# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdConfigProvider(Component):
    """An AntdConfigProvider component.
    参数配置组件AntdConfigProvider

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - algorithm (a value equal to: 'default', 'dark', 'compact' | list of a value equal to: 'default', 'dark', 'compact's; default 'default'):
        为内部组件设置快捷主题算法，支持多种主题组合，可选项有`'default'`、`'dark'`、`'compact'`
        默认值：`'default'`.

    - cssVar (dict; optional):
        是否开启`CSS`变量模式，具体参考：https://ant-design.antgroup.com/docs/react/css-variables
        默认值：`False`.

        `cssVar` is a boolean | dict with keys:

        - prefix (string; optional)

        - key (string; optional)

    - useOldTheme (a value equal to: 'default', 'dark'; optional):
        是否强制使用`0.3.x`版本之前的主题样式，可选项有`'default'`、`'dark'`.

    - primaryColor (string; optional):
        主题色.

    - componentDisabled (boolean; optional):
        是否针后代元素中的所有组件强制设置禁用状态.

    - componentSize (a value equal to: 'small', 'middle', 'large'; optional):
        强制设置后代元素的尺寸规格，可选项有`'small'`、`'middle'`、`'large'`，其中`'default'`兼容`'middle'`.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; optional):
        强制设置后代元素的语言，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）.

    - wavesDisabled (boolean; default False):
        是否禁用内部组件水波纹动效 默认值：`False`.

    - token (dict; optional):
        配置`design token`相关参数.

        `token` is a dict with keys:

        - motion (boolean; optional):
            是否开启动画效果 默认值：`True`.

    - componentsToken (dict; optional):
        配置针对具体组件的`design token`相关参数.

        `componentsToken` is a dict with strings as keys and values of
        type dict with keys:

        - algorithm (boolean; optional):
            是否开启派生样式自动推导运算 默认值：`False`.

    - compatibilityMode (boolean; default False):
        是否开启针对`88`及以下版本`Chromium`内核浏览器的向下兼容模式 默认值：`False`.

    - enableLayer (boolean; default False):
        是否启用layer样式降权 默认值：`False`."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdConfigProvider'
    CssVar = TypedDict('CssVar', {'prefix': NotRequired[str], 'key': NotRequired[str]})

    Token = TypedDict('Token', {'motion': NotRequired[bool]})

    ComponentsToken = TypedDict('ComponentsToken', {'algorithm': NotRequired[bool]})

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        algorithm: typing.Optional[
            typing.Union[
                Literal['default', 'dark', 'compact'],
                typing.Sequence[Literal['default', 'dark', 'compact']],
            ]
        ] = None,
        cssVar: typing.Optional[typing.Union[bool, 'CssVar']] = None,
        useOldTheme: typing.Optional[Literal['default', 'dark']] = None,
        primaryColor: typing.Optional[str] = None,
        componentDisabled: typing.Optional[bool] = None,
        componentSize: typing.Optional[Literal['small', 'middle', 'large']] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        wavesDisabled: typing.Optional[bool] = None,
        token: typing.Optional['Token'] = None,
        componentsToken: typing.Optional[
            typing.Dict[typing.Union[str, float, int], 'ComponentsToken']
        ] = None,
        compatibilityMode: typing.Optional[bool] = None,
        enableLayer: typing.Optional[bool] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'algorithm',
            'cssVar',
            'useOldTheme',
            'primaryColor',
            'componentDisabled',
            'componentSize',
            'locale',
            'wavesDisabled',
            'token',
            'componentsToken',
            'compatibilityMode',
            'enableLayer',
        ]
        self._valid_wildcard_attributes = []
        self.available_properties = [
            'id',
            'key',
            'children',
            'algorithm',
            'cssVar',
            'useOldTheme',
            'primaryColor',
            'componentDisabled',
            'componentSize',
            'locale',
            'wavesDisabled',
            'token',
            'componentsToken',
            'compatibilityMode',
            'enableLayer',
        ]
        self.available_wildcard_properties = []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdConfigProvider, self).__init__(children=children, **args)


setattr(AntdConfigProvider, '__init__', _explicitize_args(AntdConfigProvider.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdTabs(Component):
    """An AntdTabs component.
    标签页组件AntdTabs

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - type (a value equal to: 'line', 'card', 'editable-card'; default 'line'):
        标签页类型，可选项有`'line'`、`'card'`、`'editable-card'` 默认值：`'line'`.

    - items (list of dicts; optional):
        定义标签项.

        `items` is a list of dicts with keys:

        - label (a list of or a singular dash component, string or number; optional):
            组件型，标签页标题.

        - key (string; optional):
            标签页唯一识别id.

        - children (a list of or a singular dash component, string or number; optional):
            组件型，标签页内部元素.

        - icon (a list of or a singular dash component, string or number; optional):
            组件型，标签页图标元素.

        - closeIcon (boolean | a list of or a singular dash component, string or number; optional):
            `'editable-card'`型标签页可用，用于自定义关闭按钮，设置为`None`或`False`时会隐藏默认的关闭按钮.

        - destroyInactiveTabPane (boolean; optional):
            是否在当前标签页隐藏时，自动销毁当前标签页内部元素 默认值：`False`.

        - disabled (boolean; optional):
            是否禁用当前标签页 默认值：`False`.

        - forceRender (boolean; optional):
            初始化是否强制渲染当前标签页内部元素 默认值：`False`.

        - closable (boolean; optional):
            `'editable-card'`型标签页可用，控制当前标签页是否可被关闭 默认值：`True`.

        - contextMenu (list of dicts; optional):
            为当前标签页标题配置右键菜单相关参数.

            `contextMenu` is a list of dicts with keys:

            - key (string; optional):

                当前右键菜单项唯一标识id.

            - label (string; optional):

                当前右键菜单项标题.

            - icon (string; optional):

                当前右键菜单项前缀图标类型，`iconRenderer`为`'AntdIcon'`时同`AntdIcon`同名参数，`iconRenderer`为`'fontawesome'`时为css类名.

            - iconRenderer (a value equal to: 'AntdIcon', 'fontawesome'; optional):

                当前右键菜单项前缀图标渲染方式，可选项有`'AntdIcon'`、`'fontawesome'`.

    - itemKeys (list of strings; optional):
        监听当前各标签页`key`值，顺序与`items`一致.

    - activeKey (string; optional):
        监听或设置当前激活的标签页对应`key`值.

    - defaultActiveKey (string; optional):
        初始化激活的标签页对应`key`值.

    - disabledTabKeys (list of strings; optional):
        呈现禁用状态的标签页`key`值数组，优先级高于`items`中各标签页的`disabled`设定.

    - tabPosition (a value equal to: 'top', 'left', 'right', 'bottom'; default 'top'):
        标签页切换控件显示方位，可选项有`'top'`、`'left'`、`'right'`、`'bottom'` 默认值：`'top'`.

    - size (a value equal to: 'small', 'default', 'large'; default 'default'):
        当前组件尺寸规格，可选项有`'small'`、`'default'`、`'large'` 默认值：'default'.

    - centered (boolean; default False):
        是否居中显示标签页切换控件 默认值：`False`.

    - indicator (dict; optional):
        配置指示条长度及对齐方式.

        `indicator` is a dict with keys:

        - size (number; optional):
            指示条像素宽度，当传入负数时，表示在完整宽度基础上应减去的像素宽度，默认与标签卡片同宽.

        - align (a value equal to: 'start', 'center', 'end'; optional):
            指示条对齐方式，可选项有`'start'`、`'center'`、`'end'`.

    - tabBarGutter (number; optional):
        标签卡片之间的像素间距.

    - tabBarStyle (dict; optional):
        标签卡片css样式.

    - inkBarAnimated (boolean; default True):
        标签卡片切换是否添加动画效果 默认值：`True`.

    - tabPaneAnimated (boolean; default False):
        标签内容切换是否添加动画效果 默认值：`False`.

    - latestDeletePane (string; optional):
        监听最近一次删除操作对应的标签页`key`值.

    - tabCloseCounts (number; default 0):
        标签页关闭按钮累计点击次数 默认值：`0`.

    - tabBarLeftExtraContent (a list of or a singular dash component, string or number; optional):
        组件型，第一方位额外元素.

    - tabBarRightExtraContent (a list of or a singular dash component, string or number; optional):
        组件型，第二方位额外元素.

    - tabCount (number; optional):
        监听标签页数量.

    - destroyInactiveTabPane (boolean; default False):
        统一设置是否自动销毁取消激活状态的标签页内部元素.

    - clickedContextMenu (dict; optional):
        监听标签页标题右键菜单项相关点击事件.

        `clickedContextMenu` is a dict with keys:

        - tabKey (string; optional):
            被点击的右键菜单项对应标签页`key`值.

        - menuKey (string; optional):
            被点击的右键菜单项对应`key`值.

        - timestamp (number; optional):
            事件对应时间戳信息.

    - placeholder (a list of or a singular dash component, string or number; optional):
        当`items`为空或长度为`0`时，替代进行占位显示的内容.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'activeKey's; optional):
        开启属性持久化功能的若干属性名，可选项有`'activeKey'` 默认值：`['activeKey']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = [
        'items[].label',
        'items[].children',
        'items[].icon',
        'items[].closeIcon',
        'tabBarLeftExtraContent',
        'tabBarRightExtraContent',
        'placeholder',
    ]
    _base_nodes = ['tabBarLeftExtraContent', 'tabBarRightExtraContent', 'placeholder', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTabs'
    ItemsContextMenu = TypedDict(
        'ItemsContextMenu',
        {
            'key': NotRequired[str],
            'label': NotRequired[str],
            'icon': NotRequired[str],
            'iconRenderer': NotRequired[Literal['AntdIcon', 'fontawesome']],
        },
    )

    Items = TypedDict(
        'Items',
        {
            'label': NotRequired[ComponentType],
            'key': NotRequired[str],
            'children': NotRequired[ComponentType],
            'icon': NotRequired[ComponentType],
            'closeIcon': NotRequired[typing.Union[bool, ComponentType]],
            'destroyInactiveTabPane': NotRequired[bool],
            'disabled': NotRequired[bool],
            'forceRender': NotRequired[bool],
            'closable': NotRequired[bool],
            'contextMenu': NotRequired[typing.Sequence['ItemsContextMenu']],
        },
    )

    Indicator = TypedDict(
        'Indicator',
        {'size': NotRequired[NumberType], 'align': NotRequired[Literal['start', 'center', 'end']]},
    )

    ClickedContextMenu = TypedDict(
        'ClickedContextMenu',
        {
            'tabKey': NotRequired[str],
            'menuKey': NotRequired[str],
            'timestamp': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        type: typing.Optional[Literal['line', 'card', 'editable-card']] = None,
        items: typing.Optional[typing.Sequence['Items']] = None,
        itemKeys: typing.Optional[typing.Sequence[str]] = None,
        activeKey: typing.Optional[str] = None,
        defaultActiveKey: typing.Optional[str] = None,
        disabledTabKeys: typing.Optional[typing.Sequence[str]] = None,
        tabPosition: typing.Optional[Literal['top', 'left', 'right', 'bottom']] = None,
        size: typing.Optional[Literal['small', 'default', 'large']] = None,
        centered: typing.Optional[bool] = None,
        indicator: typing.Optional['Indicator'] = None,
        tabBarGutter: typing.Optional[NumberType] = None,
        tabBarStyle: typing.Optional[dict] = None,
        inkBarAnimated: typing.Optional[bool] = None,
        tabPaneAnimated: typing.Optional[bool] = None,
        latestDeletePane: typing.Optional[str] = None,
        tabCloseCounts: typing.Optional[NumberType] = None,
        tabBarLeftExtraContent: typing.Optional[ComponentType] = None,
        tabBarRightExtraContent: typing.Optional[ComponentType] = None,
        tabCount: typing.Optional[NumberType] = None,
        destroyInactiveTabPane: typing.Optional[bool] = None,
        clickedContextMenu: typing.Optional['ClickedContextMenu'] = None,
        placeholder: typing.Optional[ComponentType] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['activeKey']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'type',
            'items',
            'itemKeys',
            'activeKey',
            'defaultActiveKey',
            'disabledTabKeys',
            'tabPosition',
            'size',
            'centered',
            'indicator',
            'tabBarGutter',
            'tabBarStyle',
            'inkBarAnimated',
            'tabPaneAnimated',
            'latestDeletePane',
            'tabCloseCounts',
            'tabBarLeftExtraContent',
            'tabBarRightExtraContent',
            'tabCount',
            'destroyInactiveTabPane',
            'clickedContextMenu',
            'placeholder',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'type',
            'items',
            'itemKeys',
            'activeKey',
            'defaultActiveKey',
            'disabledTabKeys',
            'tabPosition',
            'size',
            'centered',
            'indicator',
            'tabBarGutter',
            'tabBarStyle',
            'inkBarAnimated',
            'tabPaneAnimated',
            'latestDeletePane',
            'tabCloseCounts',
            'tabBarLeftExtraContent',
            'tabBarRightExtraContent',
            'tabCount',
            'destroyInactiveTabPane',
            'clickedContextMenu',
            'placeholder',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdTabs, self).__init__(**args)


setattr(AntdTabs, '__init__', _explicitize_args(AntdTabs.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdFormRender(Component):
    """An AntdFormRender component.


    Keyword arguments:

    - id (string; optional):
        组件id.

    - className (string | dict; optional):
        css类名.

    - key (string; optional):
        辅助刷新用唯一标识key值.

    - schema (dict; required):
        必填，设置表单的schema.

        `schema` is a dict with keys:

        - type (a value equal to: 'object'; optional):
            固定配置为type: 'object'.

        - displayType (a value equal to: 'column', 'row', 'inline'; optional):
            设置表单表单项label布局方式，可选的有'column'、'row'与'inline'，默认为'column'.

        - column (number; optional):
            设置表单布局，一行应该有几列，默认为3.

        - labelWidth (number; optional):
            设置表单项标签的宽度.

        - maxWidth (number; optional):
            设置表单项控件的最大宽度.

        - labelCol (number; optional):
            设置表单标签占位格数.

        - fieldCol (number; optional):
            设置表单控件占位格数.

        - properties (dict; optional):
            设置表单控件.

            `properties` is a dict with strings as keys and values of type
            dict with keys:

            - type (a value equal to: 'string', 'number', 'boolean', 'array', 'range', 'html', 'block'; optional):

                设置表单字段的类型，可选的有'string'、'number'、'boolean'、'array'、'range'、'html'、'block'.

            - title (string; optional):

                设置表单字段的标签.

            - labelWidth (number

                  Or string; optional):

                设置表单项标签的宽度.

            - maxWidth (number

          Or string; optional):

                设置表单项控件的最大宽度.

            - labelCol (number | string; optional):

                设置表单标签占位格数.

            - fieldCol (number | string; optional):

                设置表单控件占位格数.

            - cellSpan (number | string; optional):

                设置表单项跨列展示，目前需配合lableWidth来使用，否则无法与其他表单项在样式上对齐，通过配置单个表单项的labelCol、fieldCol勉强能改善.

            - span (number | string; optional):

                设置表单项列宽度，表单布局会被切割成 24 等份，可以通过设置 span 来自定义表单项所占的宽度.

            - widget (a value equal to: 'input', 'inputNumber', 'select', 'multiSelect', 'radio', 'checkboxes', 'textArea', 'checkbox', 'switch', 'rate', 'slider', 'datePicker', 'dateRange', 'timePicker', 'timeRange', 'cascader', 'treeSelect', 'color', 'imageInput', 'urlInput', 'html'; optional):

                设置指定渲染的控件名称.

            - placeholder (string | list of strings; optional):

                设置输入内容提示.

            - description (string; optional):

                设置副标题描述.

            - tooltip (dict; optional):

                设置气泡提示，支持html格式，可传入一个antd的tooltip配置对象支持更多配置.

                `tooltip` is a string | dict with keys:

                - title (boolean | number | string | dict | list; optional):

                    设置显示的文字内容.

                - placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight'; optional):

                    设置气泡框的位置，可选的有'top'、'left'、'right'、'bottom'、'topLeft'

                    、'topRight'、'bottomLeft'、'bottomRight'、'leftTop'、'leftBottom'

                    、'rightTop'、'rightBottom'，默认为'top'.

                - color (string; optional):

                    设置背景颜色.

                - mouseEnterDelay (number; optional):

                    设置鼠标移入后延时多少才显示 Tooltip，单位：秒，默认为0.1.

                - mouseLeaveDelay (number; optional):

                    设置鼠标移出后延时多少才隐藏 Tooltip，单位：秒，默认为0.1.

                - overlayClassName (string | dict; optional):

                    设置卡片css类.

                - overlayStyle (dict; optional):

                    设置卡片样式.

                - overlayInnerStyle (dict; optional):

                    设置卡片内容区域的样式.

                - trigger (a value equal to: 'hover', 'focus', 'click' | list of a value equal to: 'hover', 'focus', 'click's; optional):

                    设置触发行为，可选的有'hover'、'focus'、'click'，或是以上多个组成的数组，默认为'hover'.

                - zIndex (number; optional):

                    设置悬浮层zIndex.

                - arrow (a value equal to: 'show', 'hide', 'center'; optional):

                    设置修改箭头的显示状态以及修改箭头是否指向目标元素中心，默认为'show'.

                - fresh (boolean; optional):

                    用于设置是否始终保持更新内容，默认为False。默认情况下，Tooltip

                    在关闭时会缓存内容，设置该属性后会始终保持更新。.

                - open (boolean; optional):

                    用于监听或控制当前tooltip的显隐，默认为False.

                - autoAdjustOverflow (boolean; optional):

                    用于设置气泡被遮挡时自动调整位置,默认为True.

                - defaultOpen (boolean; optional):

                    设置默认是否显隐，默认为False.

                - destroyTooltipOnHide (boolean; optional):

                    设置关闭后是否销毁Tooltip，默认为False.

            - extra (string; optional):

                设置更多的说明信息，支持html格式，会紧贴在元素下面一行展示.

            - required (boolean | string; optional):

                设置是否必填，默认为False.

            - min (number | string; optional):

                设置string类型为字符串最小长度；number类型时为最小值；array 类型时为数组最小长度.

            - max (number | string; optional):

                设置string类型为字符串最大长度；number类型时为最大值；array 类型时为数组最大长度.

            - format (a value equal to: 'image', 'textarea', 'color', 'email', 'url', 'dateTime', 'date', 'time', 'upload'; optional):

                在已设置的type下，如何处理这个type.

            - rules (list of dicts; optional):

                设置表单元素的校验规则.

                `rules` is a list of dicts with keys:

                - defaultField (dict; optional):

                    仅在 type 为 array 类型时有效，用于指定数组元素的校验规则.

                - enum (boolean | number | string | dict | list; optional):

                    是否匹配枚举中的值（需要将 type 设置为 enum）.

                - fields (boolean | number | string | dict | list; optional):

                    仅在 type 为 array 或 object 类型时有效，用于指定子元素的校验规则.

                - len (number; optional):

                    string 类型时为字符串长度；number 类型时为确定数字； array 类型时为数组长度.

                - max (number; optional):

                    必须设置 type：string 类型为字符串最大长度；number 类型时为最大值；array 类型时为数组最大长度.

                - message (string; optional):

                    错误信息，不设置时会通过模板自动生成.

                - min (number; optional):

                    必须设置 type：string 类型为字符串最小长度；number 类型时为最小值；array 类型时为数组最小长度.

                - pattern (string; optional):

                    正则表达式匹配.

                - required (boolean; optional):

                    是否为必选字段.

                - type (a value equal to: 'string', 'number', 'boolean', 'method', 'regexp', 'integer', 'float', 'array', 'object', 'enum', 'date', 'url', 'hex', 'email', 'any'; optional):

                    类型，常见有 string |number |boolean |url | email等.

                - validateTrigger (a value equal to: 'onChange', 'onBlur', 'onFocus'; optional):

                    设置触发验证时机，可选值有onChange、onBlur、onFocus，默认为onChange.

                - validator (string; optional):

                    设置自定义校验，值需要是字符串格式的js函数.

                - warningOnly (boolean; optional):

                    仅警告，不阻塞表单提交.

                - whitespace (boolean; optional):

                    如果字段仅包含空格则校验不通过，只在 type: 'string' 时生效.

            - hidden (boolean | string; optional):

                设置是否隐藏，默认为False.

            - disabled (boolean | string; optional):

                设置是否禁用，默认为False.

            - readOnly (boolean | string; optional):

                设置是否为可读模式，默认为False.

            - readOnlyWidget (string; optional):

                指定只读渲染组件名称.

            - dependencies (list of strings; optional):

                设置表单依赖元素，当依赖的元素更新时，会触发本元素的重新渲染，用于复杂的表单联动.

            - className (string; optional):

                设置自定义控件class名称.

            - reserveLabel (boolean | string; optional):

                当title未设置时，通过配置reserveLabel:

                True可以保留labelWidth占位，使得输入控件和其他控件上下对齐.

            - props (dict; optional):

                设置额外属性，如果使用的是antd组件，对应的就是antd组件的其他属性. | dict with keys:

            - type (a value equal to: 'object'; optional):

                固定配置为type: 'object'.

            - title (string; optional):

                设置标题.

            - widget (a value equal to: 'collapse', 'card', 'lineTitle', 'subInline'; optional):

                设置希望使用的嵌套组件名称，可选的有'collapse'、'card'、'lineTitle'、'subInline'，默认为'card'.

            - properties (dict; optional):

                设置表单元素集合.

            - column (number | string; optional):

                设置表单布局，一行应该有几列，默认为3.

            - description (string; optional):

                设置副标题描述.

            - tooltip (dict; optional):

                设置气泡提示，支持html格式，可传入一个antd的tooltip配置对象支持更多配置.

                `tooltip` is a string | dict with keys:

                - title (boolean | number | string | dict | list; optional):

                    设置显示的文字内容.

                - placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight'; optional):

                    设置气泡框的位置，可选的有'top'、'left'、'right'、'bottom'、'topLeft'

                    、'topRight'、'bottomLeft'、'bottomRight'、'leftTop'、'leftBottom'

                    、'rightTop'、'rightBottom'，默认为'top'.

                - color (string; optional):

                    设置背景颜色.

                - mouseEnterDelay (number; optional):

                    设置鼠标移入后延时多少才显示 Tooltip，单位：秒，默认为0.1.

                - mouseLeaveDelay (number; optional):

                    设置鼠标移出后延时多少才隐藏 Tooltip，单位：秒，默认为0.1.

                - overlayClassName (string | dict; optional):

                    设置卡片css类.

                - overlayStyle (dict; optional):

                    设置卡片样式.

                - overlayInnerStyle (dict; optional):

                    设置卡片内容区域的样式.

                - trigger (a value equal to: 'hover', 'focus', 'click' | list of a value equal to: 'hover', 'focus', 'click's; optional):

                    设置触发行为，可选的有'hover'、'focus'、'click'，或是以上多个组成的数组，默认为'hover'.

                - zIndex (number; optional):

                    设置悬浮层zIndex.

                - arrow (a value equal to: 'show', 'hide', 'center'; optional):

                    设置修改箭头的显示状态以及修改箭头是否指向目标元素中心，默认为'show'.

                - fresh (boolean; optional):

                    用于设置是否始终保持更新内容，默认为False。默认情况下，Tooltip

                    在关闭时会缓存内容，设置该属性后会始终保持更新。.

                - open (boolean; optional):

                    用于监听或控制当前tooltip的显隐，默认为False.

                - autoAdjustOverflow (boolean; optional):

                    用于设置气泡被遮挡时自动调整位置,默认为True.

                - defaultOpen (boolean; optional):

                    设置默认是否显隐，默认为False.

                - destroyTooltipOnHide (boolean; optional):

                    设置关闭后是否销毁Tooltip，默认为False.

            - props (dict; optional):

                设置额外属性，透传到对应的嵌套组件中. | dict with keys:

            - type (a value equal to: 'array'; optional):

                固定配置为type: 'array'.

            - title (string; optional):

                设置标题.

            - widget (a value equal to: 'cardList', 'simpleList', 'tableList', 'drawerList', 'virtualList'; optional):

                设置希望使用的列表组件名称，可选的有'cardList'、'simpleList'、'tableList'、'drawerList'、'virtualList'，默认为'cardList'.

            - max (number | string; optional):

                设置列表的最大长度.

            - min (number | string; optional):

                设置列表的最小长度.

            - props (dict; optional):

                设置列表控件.

                `props` is a dict with keys:

                - addBtnProps (dict; optional):

                    设置添加按钮属性，参考 Antd Button Props().

                - delConfirmProps (dict; optional):

                    设置删除确认弹窗属性，参考 Antd PopConfirm Props.

                - actionColumnProps (dict; optional):

                    设置tableList | drawerList | virtualList 中操作列的属性，参考 Antd

                    Table ColumnType。 其中 title 使用 colHeaderText 代替。.

                - hideAdd (boolean; optional):

                    设置是否隐藏添加按钮.

                - hideCopy (boolean; optional):

                    设置是否隐藏复制按钮.

                - hideMove (boolean; optional):

                    设置是否隐藏移动按钮.

                - hideDelete (boolean; optional):

                    设置是否隐藏删除按钮.

            - items (dict; optional):

                动态项配置，可以是一个嵌套控件.

    - displayType (a value equal to: 'column', 'row', 'inline'; default 'column'):
        设置表单布局模式，表单元素与 label 同行 or 分两行展示, inline 则整个展示自然顺排，
        可选的有'column'、'row'与'inline'，默认为'column'.

    - labelAlign (a value equal to: 'left', 'right'; default 'right'):
        设置label标签的文本对齐方式，可选的有'left'和'right'，默认为'right'.

    - lableWidth (number; optional):
        设置表单标签固定宽度.

    - maxWidth (number; optional):
        设置表单项控件的最大宽度.

    - labelCol (number; optional):
        设置表单标签占位格数.

    - fieldCol (number; optional):
        设置表单控件占位格数.

    - colon (boolean; default True):
        设置是否是否显示label后面的冒号，默认为True.

    - globalConfig (dict; optional):
        设置表单全局配置.

        `globalConfig` is a dict with keys:

        - mustacheDisabled (boolean; optional):
            设置是否禁用表达式.

        - listOperate (dict; optional):
            设置列表表单配置.

            `listOperate` is a dict with keys:

            - btnType (a value equal to: 'icon', 'text'; optional):
                设置列表表单操作按钮样式.

            - hideMove (boolean; optional):
                设置是否隐藏移动按钮.

    - watch (dict with strings as keys and values of type string; optional):
        监听表单的数据变化，属性值需要是字符串格式的js函数.

    - removeHiddenData (boolean; default True):
        设置提交数据的时候是否去掉已经被隐藏的元素的数据，默认为True.

    - readOnly (boolean; default False):
        设否开启只读模式，一般用于预览展示，全文text展示，默认为False.

    - column (number; default 1):
        设置一行展示多少列.

    - disabled (boolean; default False):
        设置是否禁用全部表单项，默认为False.

    - scrollToFirstError (boolean; default False):
        设置提交失败是否自动滚动到第一个错误字段，默认为False.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-CN'):
        设置展示语言，目前只支持中文、英文， 可选的有'zh-CN'与'en-US'，默认为'zh-CN'.

    - footer (dict; optional):
        设置底部操作区域.

        `footer` is a boolean | dict with keys:

        - submit (dict; optional):
            设置提交按钮.

            `submit` is a dict with keys:

            - text (string; optional):
                设置按钮文字.

            - hide (boolean; optional):
                设置是否显示.

            - btnProps (dict; optional):
                设置其他按钮属性，参考 Antd Button Props().

        - reset (dict; optional):
            设置重置按钮.

            `reset` is a dict with keys:

            - text (string; optional):
                设置按钮文字.

            - hide (boolean; optional):
                设置是否显示.

            - btnProps (dict; optional):
                设置其他按钮属性，参考 Antd Button Props(). | a list of or a singular dash component, string or number

    - configProvider (dict; optional):
        同antd的configProvider.

    - validateMessages (dict; optional):
        设置默认的校验提示信息.

        `validateMessages` is a dict with keys:

        - default (string; optional)

        - required (string; optional)

        - whitespace (string; optional)

        - date (dict; optional)

            `date` is a dict with keys:

            - format (string; optional)

            - parse (string; optional)

            - invalid (string; optional)

        - types (dict; optional)

            `types` is a dict with keys:

            - string (string; optional)

            - method (string; optional)

            - array (string; optional)

            - object (string; optional)

            - number (string; optional)

            - date (string; optional)

            - boolean (string; optional)

            - integer (string; optional)

            - float (string; optional)

            - regexp (string; optional)

            - email (string; optional)

            - url (string; optional)

            - hex (string; optional)

        - string (dict; optional)

            `string` is a dict with keys:

            - len (string; optional)

            - min (string; optional)

            - max (string; optional)

            - range (string; optional)

        - number (dict; optional)

            `number` is a dict with keys:

            - len (string; optional)

            - min (string; optional)

            - max (string; optional)

            - range (string; optional)

        - array (dict; optional)

            `array` is a dict with keys:

            - len (string; optional)

            - min (string; optional)

            - max (string; optional)

            - range (string; optional)

        - pattern (dict; optional)

            `pattern` is a dict with keys:

            - mismatch (string; optional)

    - values (dict; optional):
        设置与监听表单数据.

    - validateStatuses (boolean; optional):
        监听表单校验结果.

    - submitForm (boolean; optional):
        控制参数，用于提交表单时手动搜集表单的校验结果，回调设置为True后会自动变为False.

    - submitFormClicks (number; default 0):
        辅助监听表单提交参数.

    - resetForm (boolean; optional):
        控制参数，用于重置表单项校验状态（不能重置表单项包裹的组件的值，需要通过回调重置表单项包裹的组件的值），回调设置为True后会自动变为False.

    - resetFormClicks (number; default 0):
        辅助监听表单重置参数.

    - loading_state (dict; optional)

        `loading_state` is a dict with keys:

        - is_loading (boolean; optional):
            Determines if the component is loading or not.

        - prop_name (string; optional):
            Holds which property is loading.

        - component_name (string; optional):
            Holds the name of the component that is loading."""

    _children_props: typing.List[str] = ['footer']
    _base_nodes = ['footer', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFormRender'
    SchemaPropertiesTooltip = TypedDict(
        'SchemaPropertiesTooltip',
        {
            'title': NotRequired[typing.Any],
            'placement': NotRequired[
                Literal[
                    'top',
                    'left',
                    'right',
                    'bottom',
                    'topLeft',
                    'topRight',
                    'bottomLeft',
                    'bottomRight',
                ]
            ],
            'color': NotRequired[str],
            'mouseEnterDelay': NotRequired[NumberType],
            'mouseLeaveDelay': NotRequired[NumberType],
            'overlayClassName': NotRequired[typing.Union[str, dict]],
            'overlayStyle': NotRequired[dict],
            'overlayInnerStyle': NotRequired[dict],
            'trigger': NotRequired[
                typing.Union[
                    Literal['hover', 'focus', 'click'],
                    typing.Sequence[Literal['hover', 'focus', 'click']],
                ]
            ],
            'zIndex': NotRequired[NumberType],
            'arrow': NotRequired[Literal['show', 'hide', 'center']],
            'fresh': NotRequired[bool],
            'open': NotRequired[bool],
            'autoAdjustOverflow': NotRequired[bool],
            'defaultOpen': NotRequired[bool],
            'destroyTooltipOnHide': NotRequired[bool],
        },
    )

    SchemaPropertiesRules = TypedDict(
        'SchemaPropertiesRules',
        {
            'defaultField': NotRequired[dict],
            'enum': NotRequired[typing.Any],
            'fields': NotRequired[typing.Any],
            'len': NotRequired[NumberType],
            'max': NotRequired[NumberType],
            'message': NotRequired[str],
            'min': NotRequired[NumberType],
            'pattern': NotRequired[typing.Union[str, typing.Any]],
            'required': NotRequired[bool],
            'type': NotRequired[
                Literal[
                    'string',
                    'number',
                    'boolean',
                    'method',
                    'regexp',
                    'integer',
                    'float',
                    'array',
                    'object',
                    'enum',
                    'date',
                    'url',
                    'hex',
                    'email',
                    'any',
                ]
            ],
            'validateTrigger': NotRequired[Literal['onChange', 'onBlur', 'onFocus']],
            'validator': NotRequired[str],
            'warningOnly': NotRequired[bool],
            'whitespace': NotRequired[bool],
        },
    )

    SchemaProperties = TypedDict(
        'SchemaProperties',
        {
            'type': NotRequired[Literal['array']],
            'title': NotRequired[str],
            'widget': NotRequired[
                Literal['cardList', 'simpleList', 'tableList', 'drawerList', 'virtualList']
            ],
            'max': NotRequired[typing.Union[NumberType, str]],
            'min': NotRequired[typing.Union[NumberType, str]],
            'props': NotRequired['SchemaPropertiesProps'],
            'items': NotRequired[dict],
        },
    )

    SchemaPropertiesProps = TypedDict(
        'SchemaPropertiesProps',
        {
            'addBtnProps': NotRequired[dict],
            'delConfirmProps': NotRequired[dict],
            'actionColumnProps': NotRequired[dict],
            'hideAdd': NotRequired[bool],
            'hideCopy': NotRequired[bool],
            'hideMove': NotRequired[bool],
            'hideDelete': NotRequired[bool],
        },
    )

    Schema = TypedDict(
        'Schema',
        {
            'type': NotRequired[Literal['object']],
            'displayType': NotRequired[Literal['column', 'row', 'inline']],
            'column': NotRequired[NumberType],
            'labelWidth': NotRequired[NumberType],
            'maxWidth': NotRequired[NumberType],
            'labelCol': NotRequired[NumberType],
            'fieldCol': NotRequired[NumberType],
            'properties': NotRequired[
                typing.Dict[typing.Union[str, float, int], typing.Union['SchemaProperties']]
            ],
        },
    )

    GlobalConfigListOperate = TypedDict(
        'GlobalConfigListOperate',
        {'btnType': NotRequired[Literal['icon', 'text']], 'hideMove': NotRequired[bool]},
    )

    GlobalConfig = TypedDict(
        'GlobalConfig',
        {
            'mustacheDisabled': NotRequired[bool],
            'listOperate': NotRequired['GlobalConfigListOperate'],
        },
    )

    FooterSubmit = TypedDict(
        'FooterSubmit',
        {'text': NotRequired[str], 'hide': NotRequired[bool], 'btnProps': NotRequired[dict]},
    )

    FooterReset = TypedDict(
        'FooterReset',
        {'text': NotRequired[str], 'hide': NotRequired[bool], 'btnProps': NotRequired[dict]},
    )

    Footer = TypedDict(
        'Footer', {'submit': NotRequired['FooterSubmit'], 'reset': NotRequired['FooterReset']}
    )

    ValidateMessagesDate = TypedDict(
        'ValidateMessagesDate',
        {'format': NotRequired[str], 'parse': NotRequired[str], 'invalid': NotRequired[str]},
    )

    ValidateMessagesTypes = TypedDict(
        'ValidateMessagesTypes',
        {
            'string': NotRequired[str],
            'method': NotRequired[str],
            'array': NotRequired[str],
            'object': NotRequired[str],
            'number': NotRequired[str],
            'date': NotRequired[str],
            'boolean': NotRequired[str],
            'integer': NotRequired[str],
            'float': NotRequired[str],
            'regexp': NotRequired[str],
            'email': NotRequired[str],
            'url': NotRequired[str],
            'hex': NotRequired[str],
        },
    )

    ValidateMessagesString = TypedDict(
        'ValidateMessagesString',
        {
            'len': NotRequired[str],
            'min': NotRequired[str],
            'max': NotRequired[str],
            'range': NotRequired[str],
        },
    )

    ValidateMessagesNumber = TypedDict(
        'ValidateMessagesNumber',
        {
            'len': NotRequired[str],
            'min': NotRequired[str],
            'max': NotRequired[str],
            'range': NotRequired[str],
        },
    )

    ValidateMessagesArray = TypedDict(
        'ValidateMessagesArray',
        {
            'len': NotRequired[str],
            'min': NotRequired[str],
            'max': NotRequired[str],
            'range': NotRequired[str],
        },
    )

    ValidateMessagesPattern = TypedDict('ValidateMessagesPattern', {'mismatch': NotRequired[str]})

    ValidateMessages = TypedDict(
        'ValidateMessages',
        {
            'default': NotRequired[str],
            'required': NotRequired[str],
            'whitespace': NotRequired[str],
            'date': NotRequired['ValidateMessagesDate'],
            'types': NotRequired['ValidateMessagesTypes'],
            'string': NotRequired['ValidateMessagesString'],
            'number': NotRequired['ValidateMessagesNumber'],
            'array': NotRequired['ValidateMessagesArray'],
            'pattern': NotRequired['ValidateMessagesPattern'],
        },
    )

    LoadingState = TypedDict(
        'LoadingState',
        {
            'is_loading': NotRequired[bool],
            'prop_name': NotRequired[str],
            'component_name': NotRequired[str],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        style: typing.Optional[typing.Any] = None,
        key: typing.Optional[str] = None,
        schema: typing.Optional['Schema'] = None,
        displayType: typing.Optional[Literal['column', 'row', 'inline']] = None,
        labelAlign: typing.Optional[Literal['left', 'right']] = None,
        lableWidth: typing.Optional[NumberType] = None,
        maxWidth: typing.Optional[NumberType] = None,
        labelCol: typing.Optional[NumberType] = None,
        fieldCol: typing.Optional[NumberType] = None,
        colon: typing.Optional[bool] = None,
        globalConfig: typing.Optional['GlobalConfig'] = None,
        watch: typing.Optional[typing.Dict[typing.Union[str, float, int], str]] = None,
        removeHiddenData: typing.Optional[bool] = None,
        readOnly: typing.Optional[bool] = None,
        column: typing.Optional[NumberType] = None,
        disabled: typing.Optional[bool] = None,
        scrollToFirstError: typing.Optional[bool] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        footer: typing.Optional[typing.Union[bool, 'Footer', ComponentType]] = None,
        configProvider: typing.Optional[dict] = None,
        validateMessages: typing.Optional['ValidateMessages'] = None,
        values: typing.Optional[dict] = None,
        validateStatuses: typing.Optional[bool] = None,
        submitForm: typing.Optional[bool] = None,
        submitFormClicks: typing.Optional[NumberType] = None,
        resetForm: typing.Optional[bool] = None,
        resetFormClicks: typing.Optional[NumberType] = None,
        loading_state: typing.Optional['LoadingState'] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'className',
            'style',
            'key',
            'schema',
            'displayType',
            'labelAlign',
            'lableWidth',
            'maxWidth',
            'labelCol',
            'fieldCol',
            'colon',
            'globalConfig',
            'watch',
            'removeHiddenData',
            'readOnly',
            'column',
            'disabled',
            'scrollToFirstError',
            'locale',
            'footer',
            'configProvider',
            'validateMessages',
            'values',
            'validateStatuses',
            'submitForm',
            'submitFormClicks',
            'resetForm',
            'resetFormClicks',
            'loading_state',
        ]
        self._valid_wildcard_attributes = []
        self.available_properties = [
            'id',
            'className',
            'style',
            'key',
            'schema',
            'displayType',
            'labelAlign',
            'lableWidth',
            'maxWidth',
            'labelCol',
            'fieldCol',
            'colon',
            'globalConfig',
            'watch',
            'removeHiddenData',
            'readOnly',
            'column',
            'disabled',
            'scrollToFirstError',
            'locale',
            'footer',
            'configProvider',
            'validateMessages',
            'values',
            'validateStatuses',
            'submitForm',
            'submitFormClicks',
            'resetForm',
            'resetFormClicks',
            'loading_state',
        ]
        self.available_wildcard_properties = []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['schema']:
            if k not in args:
                raise TypeError('Required argument `' + k + '` was not specified.')

        super(AntdFormRender, self).__init__(**args)


setattr(AntdFormRender, '__init__', _explicitize_args(AntdFormRender.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdFlex(Component):
    """An AntdFlex component.
    弹性布局组件AntdFlex

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - vertical (boolean; default False):
        是否使用垂直主轴 默认值：`False`.

    - wrap (string | boolean; default 'nowrap'):
        子元素换行显示行为，同css中的flex-wrap，也可直接传入布尔型设置是否自动换行 默认值：`'nowrap'`.

    - justify (string; default 'normal'):
        子元素在主轴方向上的对齐方式，同css中的justify-content 默认值：`'normal'`.

    - align (string; default 'normal'):
        子元素在交叉轴方向上的对齐方式，同css中的align-items 默认值：`'normal'`.

    - flex (string; default 'normal'):
        同css中的flex 默认值：`'normal'`.

    - gap (string | number | a value equal to: 'small', 'middle', 'large'; optional):
        子元素之间的间隙，可选项有`'small'`、`'middle'`、`'large'`，也可传入字符型css宽度，或数值型像素宽度.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFlex'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        vertical: typing.Optional[bool] = None,
        wrap: typing.Optional[typing.Union[str, bool]] = None,
        justify: typing.Optional[str] = None,
        align: typing.Optional[str] = None,
        flex: typing.Optional[str] = None,
        gap: typing.Optional[
            typing.Union[str, NumberType, Literal['small', 'middle', 'large']]
        ] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'vertical',
            'wrap',
            'justify',
            'align',
            'flex',
            'gap',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'vertical',
            'wrap',
            'justify',
            'align',
            'flex',
            'gap',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdFlex, self).__init__(children=children, **args)


setattr(AntdFlex, '__init__', _explicitize_args(AntdFlex.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdNotification(Component):
    """An AntdNotification component.
    通知提醒框组件AntdNotification

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - message (a list of or a singular dash component, string or number; optional):
        通知提醒主要信息.

    - description (a list of or a singular dash component, string or number; optional):
        通知提醒描述信息.

    - type (a value equal to: 'default', 'success', 'error', 'info', 'warning'; default 'default'):
        通知提醒类型，可选项有`'default'`、`'success'`、`'error'`、`'info'`、`'warning'`
        默认值：`'default'`.

    - placement (a value equal to: 'top', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight'; default 'topRight'):
        通知提醒框在屏幕中的弹出位置，可选项有`'top'`、`'bottom'`、`'topLeft'`、`'topRight'`、`'bottomLeft'`、`'bottomRight'`
        默认值：`'topRight'`.

    - top (number; default 24):
        当通知从顶部弹出时，设置距离顶部的像素距离 默认值：`24`.

    - bottom (number; default 24):
        当通知从底部弹出时，设置距离底部的像素距离 默认值：`24`.

    - duration (number; default 4.5):
        通知从显示到自动消失的时长，单位：秒，当传入`None`时会一直显示 默认值：`4.5`.

    - showProgress (boolean; default False):
        是否显示自动关闭进度条 默认值：`False`.

    - pauseOnHover (boolean; default True):
        `showProgress=True`时，是否在鼠标移入时暂停进度条倒计时 默认值：`True`.

    - closable (boolean; default True):
        是否显示关闭按钮 默认值：`True`.

    - closeButton (dict; optional):
        配置右下方关闭按钮相关参数，默认不显示关闭按钮.

        `closeButton` is a dict with keys:

        - content (string; optional):
            按钮内容.

        - style (dict; optional):
            按钮css样式.

        - className (string; optional):
            按钮css类名.

        - type (a value equal to: 'default', 'primary', 'ghost', 'dashed', 'link', 'text'; optional):
            按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
            默认值：`'default'`.

        - danger (boolean; optional):
            按钮是否呈现危险状态 默认值：`False`.

    - stack (dict; default False):
        是否开启多通知自动折叠堆叠功能 默认值：`False`.

        `stack` is a boolean | dict with keys:

        - threshold (number; optional)"""

    _children_props: typing.List[str] = ['message', 'description']
    _base_nodes = ['message', 'description', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdNotification'
    CloseButton = TypedDict(
        'CloseButton',
        {
            'content': NotRequired[str],
            'style': NotRequired[dict],
            'className': NotRequired[str],
            'type': NotRequired[Literal['default', 'primary', 'ghost', 'dashed', 'link', 'text']],
            'danger': NotRequired[bool],
        },
    )

    Stack = TypedDict('Stack', {'threshold': NotRequired[NumberType]})

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        message: typing.Optional[ComponentType] = None,
        description: typing.Optional[ComponentType] = None,
        type: typing.Optional[Literal['default', 'success', 'error', 'info', 'warning']] = None,
        placement: typing.Optional[
            Literal['top', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight']
        ] = None,
        top: typing.Optional[NumberType] = None,
        bottom: typing.Optional[NumberType] = None,
        duration: typing.Optional[NumberType] = None,
        showProgress: typing.Optional[bool] = None,
        pauseOnHover: typing.Optional[bool] = None,
        closable: typing.Optional[bool] = None,
        closeButton: typing.Optional['CloseButton'] = None,
        stack: typing.Optional[typing.Union[bool, 'Stack']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'message',
            'description',
            'type',
            'placement',
            'top',
            'bottom',
            'duration',
            'showProgress',
            'pauseOnHover',
            'closable',
            'closeButton',
            'stack',
        ]
        self._valid_wildcard_attributes = []
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'message',
            'description',
            'type',
            'placement',
            'top',
            'bottom',
            'duration',
            'showProgress',
            'pauseOnHover',
            'closable',
            'closeButton',
            'stack',
        ]
        self.available_wildcard_properties = []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdNotification, self).__init__(**args)


setattr(AntdNotification, '__init__', _explicitize_args(AntdNotification.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSpoiler(Component):
    """An AntdSpoiler component.
    展开收起组件AntdSpoiler

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - contentClassName (string | dict; optional):
        内容区css类名，支持[动态css](/advanced-classname).

    - contentStyle (dict; optional):
        内容区css样式.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - hideLabel (a list of or a singular dash component, string or number; optional):
        组件型，展开状态下，收起按钮的文案内容.

    - showLabel (a list of or a singular dash component, string or number; optional):
        组件型，收起状态下，展开按钮的文案内容.

    - labelPosition (a value equal to: 'left', 'right'; default 'left'):
        展开/收起按钮的位置，可选项有`'left'`、`'right'` 默认值：`'left'`.

    - open (boolean; default False):
        监听或设置是否处于展开状态 默认值：`False`.

    - maxHeight (number; default 50):
        收起状态下，内容区域最大像素高度 默认值：`50`.

    - transitionDuration (number; default 0.1):
        展开/收起过渡动画耗时，单位：秒 默认值：`0.1`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['hideLabel', 'showLabel']
    _base_nodes = ['hideLabel', 'showLabel', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSpoiler'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        contentClassName: typing.Optional[typing.Union[str, dict]] = None,
        contentStyle: typing.Optional[dict] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        hideLabel: typing.Optional[ComponentType] = None,
        showLabel: typing.Optional[ComponentType] = None,
        labelPosition: typing.Optional[Literal['left', 'right']] = None,
        open: typing.Optional[bool] = None,
        maxHeight: typing.Optional[NumberType] = None,
        transitionDuration: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'contentClassName',
            'contentStyle',
            'locale',
            'hideLabel',
            'showLabel',
            'labelPosition',
            'open',
            'maxHeight',
            'transitionDuration',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'contentClassName',
            'contentStyle',
            'locale',
            'hideLabel',
            'showLabel',
            'labelPosition',
            'open',
            'maxHeight',
            'transitionDuration',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSpoiler, self).__init__(children=children, **args)


setattr(AntdSpoiler, '__init__', _explicitize_args(AntdSpoiler.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdRow(Component):
    """An AntdRow component.
    行组件AntdRow

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - align (a value equal to: 'top', 'middle', 'bottom'; default 'top'):
        竖直方向对齐方式，可选项有`'top'`、`'middle'`、`'bottom'` 默认值：`'top'`.

    - gutter (dict; default 0):
        网格间隔，传入数值型时为水平像素间隔，传入数组时分别设置水平、垂直像素间隔，传入字典时可为响应式各断点设置水平像素间隔.

        `gutter` is a number | list of numbers | dict with keys:

        - xs (number; optional):
            页面宽度小于567px时的水平像素间隔.

        - sm (number; optional):
            页面宽度大于等于567px时的水平像素间隔.

        - md (number; optional):
            页面宽度大于等于768px时的水平像素间隔.

        - lg (number; optional):
            页面宽度大于等于992px时的水平像素间隔.

        - xl (number; optional):
            页面宽度大于等于1200px时的水平像素间隔.

        - xxl (number; optional):
            页面宽度大于等于1600px时的水平像素间隔.

    - justify (a value equal to: 'start', 'end', 'center', 'space-around', 'space-between'; default 'start'):
        水平排列方式，可选项有`'start'`、`'end'`、`'center'`、`'space-around'`、`'space-between'`
        默认值：`'start'`.

    - wrap (boolean; default True):
        是否允许自动换行 默认值：`True`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdRow'
    Gutter = TypedDict(
        'Gutter',
        {
            'xs': NotRequired[NumberType],
            'sm': NotRequired[NumberType],
            'md': NotRequired[NumberType],
            'lg': NotRequired[NumberType],
            'xl': NotRequired[NumberType],
            'xxl': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        align: typing.Optional[Literal['top', 'middle', 'bottom']] = None,
        gutter: typing.Optional[
            typing.Union[NumberType, typing.Sequence[NumberType], 'Gutter']
        ] = None,
        justify: typing.Optional[
            Literal['start', 'end', 'center', 'space-around', 'space-between']
        ] = None,
        wrap: typing.Optional[bool] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'align',
            'gutter',
            'justify',
            'wrap',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'align',
            'gutter',
            'justify',
            'wrap',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdRow, self).__init__(children=children, **args)


setattr(AntdRow, '__init__', _explicitize_args(AntdRow.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdEmpty(Component):
    """An AntdEmpty component.
    空状态组件AntdEmpty

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - root (dict; optional):
            根元素css样式.

        - image (dict; optional):
            图标元素css样式.

        - description (dict; optional):
            描述元素css样式.

        - footer (dict; optional):
            底部元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - root (string; optional):
            根元素css类名.

        - image (string; optional):
            图标元素css类名.

        - description (string; optional):
            描述元素css类名.

        - footer (string; optional):
            底部元素css类名.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - description (a list of or a singular dash component, string or number | boolean; optional):
        描述信息内容.

    - image (string | a value equal to: 'default', 'simple'; default 'default'):
        状态图片地址，也可以使用内置图片，可选项有`'default'`、`'simple'` 默认值：`'default'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['description']
    _base_nodes = ['description', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdEmpty'
    Styles = TypedDict(
        'Styles',
        {
            'root': NotRequired[dict],
            'image': NotRequired[dict],
            'description': NotRequired[dict],
            'footer': NotRequired[dict],
        },
    )

    ClassNames = TypedDict(
        'ClassNames',
        {
            'root': NotRequired[str],
            'image': NotRequired[str],
            'description': NotRequired[str],
            'footer': NotRequired[str],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        description: typing.Optional[typing.Union[ComponentType, bool]] = None,
        image: typing.Optional[typing.Union[str, Literal['default', 'simple']]] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'styles',
            'classNames',
            'className',
            'locale',
            'description',
            'image',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'styles',
            'classNames',
            'className',
            'locale',
            'description',
            'image',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdEmpty, self).__init__(children=children, **args)


setattr(AntdEmpty, '__init__', _explicitize_args(AntdEmpty.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdImageGroup(Component):
    """An AntdImageGroup component.
    图片组合组件AntdImageGroup

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，定义组内需要嵌套的`AntdImage`组件.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - items (list of strings; optional):
        控制图片组合内部实际展示的图片资源地址数组，顺序依次展示.

    - fallback (string; optional):
        图片加载失败占位图资源地址.

    - preview (dict; default True):
        配置图片预览相关功能，传入`False`时会禁用预览功能 默认值：`True`.

        `preview` is a boolean | dict with keys:

        - src (string; optional):
            自定义预览图链接地址.

        - movable (boolean; optional):
            预览模式下是否可移动图片.

        - mask (a list of or a singular dash component, string or number; optional):
            组件型，用于自定义缩略图遮罩元素.

        - maskClassName (string; optional):
            缩略图遮罩元素css类名.

        - rootClassName (string; optional):
            缩略图根节点css类名.

        - scaleStep (number; optional):
            `1+scaleStep`值为每一步缩放的倍数 默认值：`0.5`.

        - minScale (number; optional):
            最小缩放倍数 默认值：`1`.

        - maxScale (number; optional):
            最大缩放倍数 默认值：`50`.

    - visible (boolean; optional):
        监听或设置当前图片组是否处于全屏预览状态.

    - current (number; optional):
        监听或控制当前图片预览对应切换到的图片下标.

    - disableCurrent (boolean; default True):
        是否关闭基于`current`的当前图片下标受控功能 默认值：`True`.

    - toolbarExtra (a list of or a singular dash component, string or number; optional):
        针对预览模式下的工具栏，末尾扩充自定义工具图标元素.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['preview.mask', 'toolbarExtra']
    _base_nodes = ['toolbarExtra', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdImageGroup'
    Preview = TypedDict(
        'Preview',
        {
            'src': NotRequired[str],
            'movable': NotRequired[bool],
            'mask': NotRequired[ComponentType],
            'maskClassName': NotRequired[str],
            'rootClassName': NotRequired[str],
            'scaleStep': NotRequired[NumberType],
            'minScale': NotRequired[NumberType],
            'maxScale': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        items: typing.Optional[typing.Sequence[str]] = None,
        fallback: typing.Optional[str] = None,
        preview: typing.Optional[typing.Union[bool, 'Preview']] = None,
        visible: typing.Optional[bool] = None,
        current: typing.Optional[NumberType] = None,
        disableCurrent: typing.Optional[bool] = None,
        toolbarExtra: typing.Optional[ComponentType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'locale',
            'items',
            'fallback',
            'preview',
            'visible',
            'current',
            'disableCurrent',
            'toolbarExtra',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'locale',
            'items',
            'fallback',
            'preview',
            'visible',
            'current',
            'disableCurrent',
            'toolbarExtra',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdImageGroup, self).__init__(children=children, **args)


setattr(AntdImageGroup, '__init__', _explicitize_args(AntdImageGroup.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCard(Component):
    """An AntdCard component.


    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - header (dict; optional):
            设置卡片头部区域css样式.

        - title (dict; optional):
            设置卡片标题css样式.

        - extra (dict; optional):
            设置卡片右上角的操作区域css样式.

        - cover (dict; optional):
            设置标题封面css样式.

        - body (dict; optional):
            设置卡片内容区域css样式.

        - actions (dict; optional):
            设置卡片底部操作组css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - header (string; optional):
            设置卡片头部区域css类名.

        - title (string; optional):
            设置卡片标题css类名.

        - extra (string; optional):
            设置卡片右上角的操作区域css类名.

        - cover (string; optional):
            设置标题封面css类名.

        - body (string; optional):
            设置卡片内容区域css类名.

        - actions (string; optional):
            设置卡片底部操作组css类名.

    - actions (a list of or a singular dash component, string or number; optional):
        组件型，底部操作区元素.

    - title (a list of or a singular dash component, string or number; optional):
        组件型，标题内容.

    - extraLink (dict; optional):
        配置卡片右上角额外链接相关参数.

        `extraLink` is a dict with keys:

        - content (string; optional):
            链接文字内容.

        - href (string; optional):
            链接地址.

        - target (string; optional):
            链接跳转行为.

        - className (string; optional):
            链接css类名.

        - style (dict; optional):
            链接css样式.

    - extra (a list of or a singular dash component, string or number; optional):
        组件型，卡片右上角额外元素，优先级高于`extraLink`.

    - coverImg (dict; optional):
        配置封面图片相关参数.

        `coverImg` is a dict with keys:

        - src (string; optional):
            图片资源地址.

        - alt (string; optional):
            图片alt信息.

        - className (string; optional):
            图片css类名.

        - style (dict; optional):
            图片css样式.

    - variant (a value equal to: 'outlined', 'borderless'; default 'outlined'):
        卡片形态变体，可选项有`'outlined'`、`'borderless'` 默认值：`'outlined'`.

    - hoverable (boolean; default False):
        是否在鼠标悬停时显示特殊样式 默认值：`False`.

    - size (a value equal to: 'default', 'small'; default 'default'):
        卡片尺寸规格，可选项有`'default'`、`'small'` 默认值：`'default'`.

    - nClicks (number; default 0):
        监听当前卡片累计点击次数 默认值：`0`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['actions', 'title', 'extra']
    _base_nodes = ['actions', 'title', 'extra', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCard'
    Styles = TypedDict(
        'Styles',
        {
            'header': NotRequired[dict],
            'title': NotRequired[dict],
            'extra': NotRequired[dict],
            'cover': NotRequired[dict],
            'body': NotRequired[dict],
            'actions': NotRequired[dict],
        },
    )

    ClassNames = TypedDict(
        'ClassNames',
        {
            'header': NotRequired[str],
            'title': NotRequired[str],
            'extra': NotRequired[str],
            'cover': NotRequired[str],
            'body': NotRequired[str],
            'actions': NotRequired[str],
        },
    )

    ExtraLink = TypedDict(
        'ExtraLink',
        {
            'content': NotRequired[str],
            'href': NotRequired[str],
            'target': NotRequired[str],
            'className': NotRequired[str],
            'style': NotRequired[dict],
        },
    )

    CoverImg = TypedDict(
        'CoverImg',
        {
            'src': NotRequired[str],
            'alt': NotRequired[str],
            'className': NotRequired[str],
            'style': NotRequired[dict],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        actions: typing.Optional[ComponentType] = None,
        title: typing.Optional[ComponentType] = None,
        extraLink: typing.Optional['ExtraLink'] = None,
        extra: typing.Optional[ComponentType] = None,
        coverImg: typing.Optional['CoverImg'] = None,
        variant: typing.Optional[Literal['outlined', 'borderless']] = None,
        hoverable: typing.Optional[bool] = None,
        size: typing.Optional[Literal['default', 'small']] = None,
        nClicks: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'actions',
            'title',
            'extraLink',
            'extra',
            'coverImg',
            'variant',
            'hoverable',
            'size',
            'nClicks',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'actions',
            'title',
            'extraLink',
            'extra',
            'coverImg',
            'variant',
            'hoverable',
            'size',
            'nClicks',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCard, self).__init__(children=children, **args)


setattr(AntdCard, '__init__', _explicitize_args(AntdCard.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCol(Component):
    """An AntdCol component.
    列组件AntdCol

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - span (number; optional):
        列所占宽度份数.

    - offset (number; default 0):
        列左侧间隔宽度份数 默认值：`0`.

    - order (number; default 0):
        列顺序 默认值：`0`.

    - pull (number; default 0):
        列向左移动宽度份数 默认值：`0`.

    - push (number; default 0):
        列向右移动宽度份数 默认值：`0`.

    - flex (string | number; optional):
        同css中的flex.

    - xs (dict; optional):
        配置列在页面宽度小于567px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

        `xs` is a number | dict with keys:

        - span (number; optional):
            同span参数.

        - offset (number; optional):
            同offset参数.

        - order (number; optional):
            同order参数.

        - pull (number; optional):
            同pull参数.

        - push (number; optional):
            同push参数.

    - sm (dict; optional):
        配置列在页面宽度大于等于567px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

        `sm` is a number | dict with keys:

        - span (number; optional):
            同span参数.

        - offset (number; optional):
            同offset参数.

        - order (number; optional):
            同order参数.

        - pull (number; optional):
            同pull参数.

        - push (number; optional):
            同push参数.

    - md (dict; optional):
        配置列在页面宽度大于等于768px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

        `md` is a number | dict with keys:

        - span (number; optional):
            同span参数.

        - offset (number; optional):
            同offset参数.

        - order (number; optional):
            同order参数.

        - pull (number; optional):
            同pull参数.

        - push (number; optional):
            同push参数.

    - lg (dict; optional):
        配置列在页面宽度大于等于992px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

        `lg` is a number | dict with keys:

        - span (number; optional):
            同span参数.

        - offset (number; optional):
            同offset参数.

        - order (number; optional):
            同order参数.

        - pull (number; optional):
            同pull参数.

        - push (number; optional):
            同push参数.

    - xl (dict; optional):
        配置列在页面宽度大于等于1200px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

        `xl` is a number | dict with keys:

        - span (number; optional):
            同span参数.

        - offset (number; optional):
            同offset参数.

        - order (number; optional):
            同order参数.

        - pull (number; optional):
            同pull参数.

        - push (number; optional):
            同push参数.

    - xxl (dict; optional):
        配置列在页面宽度大于等于1600px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

        `xxl` is a number | dict with keys:

        - span (number; optional):
            同span参数.

        - offset (number; optional):
            同offset参数.

        - order (number; optional):
            同order参数.

        - pull (number; optional):
            同pull参数.

        - push (number; optional):
            同push参数.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCol'
    Xs = TypedDict(
        'Xs',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'order': NotRequired[NumberType],
            'pull': NotRequired[NumberType],
            'push': NotRequired[NumberType],
        },
    )

    Sm = TypedDict(
        'Sm',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'order': NotRequired[NumberType],
            'pull': NotRequired[NumberType],
            'push': NotRequired[NumberType],
        },
    )

    Md = TypedDict(
        'Md',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'order': NotRequired[NumberType],
            'pull': NotRequired[NumberType],
            'push': NotRequired[NumberType],
        },
    )

    Lg = TypedDict(
        'Lg',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'order': NotRequired[NumberType],
            'pull': NotRequired[NumberType],
            'push': NotRequired[NumberType],
        },
    )

    Xl = TypedDict(
        'Xl',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'order': NotRequired[NumberType],
            'pull': NotRequired[NumberType],
            'push': NotRequired[NumberType],
        },
    )

    Xxl = TypedDict(
        'Xxl',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'order': NotRequired[NumberType],
            'pull': NotRequired[NumberType],
            'push': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        span: typing.Optional[NumberType] = None,
        offset: typing.Optional[NumberType] = None,
        order: typing.Optional[NumberType] = None,
        pull: typing.Optional[NumberType] = None,
        push: typing.Optional[NumberType] = None,
        flex: typing.Optional[typing.Union[str, NumberType]] = None,
        xs: typing.Optional[typing.Union[NumberType, 'Xs']] = None,
        sm: typing.Optional[typing.Union[NumberType, 'Sm']] = None,
        md: typing.Optional[typing.Union[NumberType, 'Md']] = None,
        lg: typing.Optional[typing.Union[NumberType, 'Lg']] = None,
        xl: typing.Optional[typing.Union[NumberType, 'Xl']] = None,
        xxl: typing.Optional[typing.Union[NumberType, 'Xxl']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'span',
            'offset',
            'order',
            'pull',
            'push',
            'flex',
            'xs',
            'sm',
            'md',
            'lg',
            'xl',
            'xxl',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'span',
            'offset',
            'order',
            'pull',
            'push',
            'flex',
            'xs',
            'sm',
            'md',
            'lg',
            'xl',
            'xxl',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCol, self).__init__(children=children, **args)


setattr(AntdCol, '__init__', _explicitize_args(AntdCol.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdAccordion(Component):
    """An AntdAccordion component.
    手风琴组件AntdAccordion

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - header (dict; optional):
            头部元素css样式.

        - body (dict; optional):
            内容元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - header (string; optional):
            头部元素css类名.

        - body (string; optional):
            内容元素css类名.

    - items (list of dicts; optional):
        定义手风琴子项.

        `items` is a list of dicts with keys:

        - children (a list of or a singular dash component, string or number; optional):
            当前子项内部元素.

        - className (string | dict; optional):
            当前子项css类名，支持[动态css](/advanced-classname).

        - style (dict; optional):
            当前子项css样式.

        - key (string | number; required):
            必填，当前子项唯一key值.

        - collapsible (a value equal to: 'header', 'disabled', 'icon'; optional):
            当前子项折叠触发方式，可选项有`'header'`、`'disabled'`、`'icon'`.

        - title (a list of or a singular dash component, string or number; optional):
            当前子项标题元素.

        - extra (a list of or a singular dash component, string or number; optional):
            当前子项右上角额外元素.

        - showArrow (boolean; optional):
            是否展示当前手风琴项的箭头图标 默认值：`True`.

        - forceRender (boolean; optional):
            是否强制渲染内部元素 默认值：`False`.

    - accordion (boolean; default True):
        是否开启手风琴模式 默认值：`True`.

    - activeKey (string | list of strings | number | list of numbers; optional):
        监听或设置当前处于展开状态的手风琴项key值.

    - defaultActiveKey (string | list of strings | number | list of numbers; optional):
        设置初始化处于展开状态的手风琴项key值.

    - bordered (boolean; default True):
        是否渲染边框 默认值：`True`.

    - size (a value equal to: 'large', 'middle', 'small'; default 'middle'):
        组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - collapsible (a value equal to: 'header', 'disabled', 'icon'; optional):
        设置所有子项折叠触发方式，可选项有`'header'`、`'disabled'`、`'icon'`.

    - expandIconPosition (a value equal to: 'left', 'right'; default 'left'):
        设置折叠图标位置，可选项有`'left'`、`'right'`.

    - ghost (boolean; default False):
        是否开启透明无边框模式 默认值：`False`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['items[].children', 'items[].title', 'items[].extra']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAccordion'
    Styles = TypedDict('Styles', {'header': NotRequired[dict], 'body': NotRequired[dict]})

    ClassNames = TypedDict('ClassNames', {'header': NotRequired[str], 'body': NotRequired[str]})

    Items = TypedDict(
        'Items',
        {
            'children': NotRequired[ComponentType],
            'className': NotRequired[typing.Union[str, dict]],
            'style': NotRequired[dict],
            'key': typing.Union[str, NumberType],
            'collapsible': NotRequired[Literal['header', 'disabled', 'icon']],
            'title': NotRequired[ComponentType],
            'extra': NotRequired[ComponentType],
            'showArrow': NotRequired[bool],
            'forceRender': NotRequired[bool],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        items: typing.Optional[typing.Sequence['Items']] = None,
        accordion: typing.Optional[bool] = None,
        activeKey: typing.Optional[
            typing.Union[str, typing.Sequence[str], NumberType, typing.Sequence[NumberType]]
        ] = None,
        defaultActiveKey: typing.Optional[
            typing.Union[str, typing.Sequence[str], NumberType, typing.Sequence[NumberType]]
        ] = None,
        bordered: typing.Optional[bool] = None,
        size: typing.Optional[Literal['large', 'middle', 'small']] = None,
        collapsible: typing.Optional[Literal['header', 'disabled', 'icon']] = None,
        expandIconPosition: typing.Optional[Literal['left', 'right']] = None,
        ghost: typing.Optional[bool] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'styles',
            'classNames',
            'items',
            'accordion',
            'activeKey',
            'defaultActiveKey',
            'bordered',
            'size',
            'collapsible',
            'expandIconPosition',
            'ghost',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'styles',
            'classNames',
            'items',
            'accordion',
            'activeKey',
            'defaultActiveKey',
            'bordered',
            'size',
            'collapsible',
            'expandIconPosition',
            'ghost',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdAccordion, self).__init__(**args)


setattr(AntdAccordion, '__init__', _explicitize_args(AntdAccordion.__init__))
